function BranchData() {
    this.position = -1;
    this.nodeLength = -1;
    this.src = null;
    this.evalFalse = 0;
    this.evalTrue = 0;

    this.init = function(position, nodeLength, src) {
        this.position = position;
        this.nodeLength = nodeLength;
        this.src = src;
        return this;
    }

    this.ranCondition = function(result) {
        if (result)
            this.evalTrue++;
        else
            this.evalFalse++;
    };

    this.pathsCovered = function() {
        var paths = 0;
        if (this.evalTrue > 0)
          paths++;
        if (this.evalFalse > 0)
          paths++;
        return paths;
    };

    this.covered = function() {
        return this.evalTrue > 0 && this.evalFalse > 0;
    };

    this.toJSON = function() {
        return '{"position":' + this.position
            + ',"nodeLength":' + this.nodeLength
            + ',"src":' + jscoverage_quote(this.src)
            + ',"evalFalse":' + this.evalFalse
            + ',"evalTrue":' + this.evalTrue + '}';
    };

    this.message = function() {
        if (this.evalTrue === 0 && this.evalFalse === 0)
            return 'Condition never evaluated         :\t' + this.src;
        else if (this.evalTrue === 0)
            return 'Condition never evaluated to true :\t' + this.src;
        else if (this.evalFalse === 0)
            return 'Condition never evaluated to false:\t' + this.src;
        else
            return 'Condition covered';
    };
}

BranchData.fromJson = function(jsonString) {
    var json = eval('(' + jsonString + ')');
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

BranchData.fromJsonObject = function(json) {
    var branchData = new BranchData();
    branchData.init(json.position, json.nodeLength, json.src);
    branchData.evalFalse = json.evalFalse;
    branchData.evalTrue = json.evalTrue;
    return branchData;
};

function buildBranchMessage(conditions) {
    var message = 'The following was not covered:';
    for (var i = 0; i < conditions.length; i++) {
        if (conditions[i] !== undefined && conditions[i] !== null && !conditions[i].covered())
          message += '\n- '+ conditions[i].message();
    }
    return message;
};

function convertBranchDataConditionArrayToJSON(branchDataConditionArray) {
    var array = [];
    var length = branchDataConditionArray.length;
    for (var condition = 0; condition < length; condition++) {
        var branchDataObject = branchDataConditionArray[condition];
        if (branchDataObject === undefined || branchDataObject === null) {
            value = 'null';
        } else {
            value = branchDataObject.toJSON();
        }
        array.push(value);
    }
    return '[' + array.join(',') + ']';
}

function convertBranchDataLinesToJSON(branchData) {
    if (branchData === undefined) {
        return '{}'
    }
    var json = '';
    for (var line in branchData) {
        if (json !== '')
            json += ','
        json += '"' + line + '":' + convertBranchDataConditionArrayToJSON(branchData[line]);
    }
    return '{' + json + '}';
}

function convertBranchDataLinesFromJSON(jsonObject) {
    if (jsonObject === undefined) {
        return {};
    }
    for (var line in jsonObject) {
        var branchDataJSON = jsonObject[line];
        if (branchDataJSON !== null) {
            for (var conditionIndex = 0; conditionIndex < branchDataJSON.length; conditionIndex ++) {
                var condition = branchDataJSON[conditionIndex];
                if (condition !== null) {
                    branchDataJSON[conditionIndex] = BranchData.fromJsonObject(condition);
                }
            }
        }
    }
    return jsonObject;
}
function jscoverage_quote(s) {
    return '"' + s.replace(/[\u0000-\u001f"\\\u007f-\uffff]/g, function (c) {
        switch (c) {
            case '\b':
                return '\\b';
            case '\f':
                return '\\f';
            case '\n':
                return '\\n';
            case '\r':
                return '\\r';
            case '\t':
                return '\\t';
            // IE doesn't support this
            /*
             case '\v':
             return '\\v';
             */
            case '"':
                return '\\"';
            case '\\':
                return '\\\\';
            default:
                return '\\u' + jscoverage_pad(c.charCodeAt(0).toString(16));
        }
    }) + '"';
}

function getArrayJSON(coverage) {
    var array = [];
    if (coverage === undefined)
        return array;

    var length = coverage.length;
    for (var line = 0; line < length; line++) {
        var value = coverage[line];
        if (value === undefined || value === null) {
            value = 'null';
        }
        array.push(value);
    }
    return array;
}

function jscoverage_serializeCoverageToJSON() {
    var json = [];
    for (var file in _$jscoverage) {
        var lineArray = getArrayJSON(_$jscoverage[file].lineData);
        var fnArray = getArrayJSON(_$jscoverage[file].functionData);

        json.push(jscoverage_quote(file) + ':{"lineData":[' + lineArray.join(',') + '],"functionData":[' + fnArray.join(',') + '],"branchData":' + convertBranchDataLinesToJSON(_$jscoverage[file].branchData) + '}');
    }
    return '{' + json.join(',') + '}';
}


function jscoverage_pad(s) {
    return '0000'.substr(s.length) + s;
}

function jscoverage_html_escape(s) {
    return s.replace(/[<>\&\"\']/g, function (c) {
        return '&#' + c.charCodeAt(0) + ';';
    });
}
try {
  if (typeof top === 'object' && top !== null && typeof top.opener === 'object' && top.opener !== null) {
    // this is a browser window that was opened from another window

    if (! top.opener._$jscoverage) {
      top.opener._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null) {
    // this is a browser window

    try {
      if (typeof top.opener === 'object' && top.opener !== null && top.opener._$jscoverage) {
        top._$jscoverage = top.opener._$jscoverage;
      }
    }
    catch (e) {}

    if (! top._$jscoverage) {
      top._$jscoverage = {};
    }
  }
}
catch (e) {}

try {
  if (typeof top === 'object' && top !== null && top._$jscoverage) {
    this._$jscoverage = top._$jscoverage;
  }
}
catch (e) {}
if (! this._$jscoverage) {
  this._$jscoverage = {};
}
if (! _$jscoverage['/hashchange.js']) {
  _$jscoverage['/hashchange.js'] = {};
  _$jscoverage['/hashchange.js'].lineData = [];
  _$jscoverage['/hashchange.js'].lineData[6] = 0;
  _$jscoverage['/hashchange.js'].lineData[7] = 0;
  _$jscoverage['/hashchange.js'].lineData[8] = 0;
  _$jscoverage['/hashchange.js'].lineData[9] = 0;
  _$jscoverage['/hashchange.js'].lineData[10] = 0;
  _$jscoverage['/hashchange.js'].lineData[19] = 0;
  _$jscoverage['/hashchange.js'].lineData[24] = 0;
  _$jscoverage['/hashchange.js'].lineData[25] = 0;
  _$jscoverage['/hashchange.js'].lineData[28] = 0;
  _$jscoverage['/hashchange.js'].lineData[42] = 0;
  _$jscoverage['/hashchange.js'].lineData[43] = 0;
  _$jscoverage['/hashchange.js'].lineData[52] = 0;
  _$jscoverage['/hashchange.js'].lineData[55] = 0;
  _$jscoverage['/hashchange.js'].lineData[56] = 0;
  _$jscoverage['/hashchange.js'].lineData[57] = 0;
  _$jscoverage['/hashchange.js'].lineData[59] = 0;
  _$jscoverage['/hashchange.js'].lineData[61] = 0;
  _$jscoverage['/hashchange.js'].lineData[65] = 0;
  _$jscoverage['/hashchange.js'].lineData[67] = 0;
  _$jscoverage['/hashchange.js'].lineData[72] = 0;
  _$jscoverage['/hashchange.js'].lineData[83] = 0;
  _$jscoverage['/hashchange.js'].lineData[85] = 0;
  _$jscoverage['/hashchange.js'].lineData[86] = 0;
  _$jscoverage['/hashchange.js'].lineData[89] = 0;
  _$jscoverage['/hashchange.js'].lineData[93] = 0;
  _$jscoverage['/hashchange.js'].lineData[94] = 0;
  _$jscoverage['/hashchange.js'].lineData[101] = 0;
  _$jscoverage['/hashchange.js'].lineData[107] = 0;
  _$jscoverage['/hashchange.js'].lineData[111] = 0;
  _$jscoverage['/hashchange.js'].lineData[114] = 0;
  _$jscoverage['/hashchange.js'].lineData[115] = 0;
  _$jscoverage['/hashchange.js'].lineData[119] = 0;
  _$jscoverage['/hashchange.js'].lineData[120] = 0;
  _$jscoverage['/hashchange.js'].lineData[122] = 0;
  _$jscoverage['/hashchange.js'].lineData[127] = 0;
  _$jscoverage['/hashchange.js'].lineData[134] = 0;
  _$jscoverage['/hashchange.js'].lineData[135] = 0;
  _$jscoverage['/hashchange.js'].lineData[136] = 0;
  _$jscoverage['/hashchange.js'].lineData[138] = 0;
  _$jscoverage['/hashchange.js'].lineData[148] = 0;
  _$jscoverage['/hashchange.js'].lineData[151] = 0;
  _$jscoverage['/hashchange.js'].lineData[152] = 0;
  _$jscoverage['/hashchange.js'].lineData[156] = 0;
  _$jscoverage['/hashchange.js'].lineData[157] = 0;
  _$jscoverage['/hashchange.js'].lineData[158] = 0;
  _$jscoverage['/hashchange.js'].lineData[165] = 0;
  _$jscoverage['/hashchange.js'].lineData[166] = 0;
  _$jscoverage['/hashchange.js'].lineData[167] = 0;
  _$jscoverage['/hashchange.js'].lineData[168] = 0;
  _$jscoverage['/hashchange.js'].lineData[169] = 0;
  _$jscoverage['/hashchange.js'].lineData[182] = 0;
  _$jscoverage['/hashchange.js'].lineData[192] = 0;
  _$jscoverage['/hashchange.js'].lineData[199] = 0;
  _$jscoverage['/hashchange.js'].lineData[204] = 0;
  _$jscoverage['/hashchange.js'].lineData[205] = 0;
  _$jscoverage['/hashchange.js'].lineData[206] = 0;
  _$jscoverage['/hashchange.js'].lineData[208] = 0;
  _$jscoverage['/hashchange.js'].lineData[209] = 0;
  _$jscoverage['/hashchange.js'].lineData[210] = 0;
  _$jscoverage['/hashchange.js'].lineData[211] = 0;
  _$jscoverage['/hashchange.js'].lineData[215] = 0;
  _$jscoverage['/hashchange.js'].lineData[217] = 0;
  _$jscoverage['/hashchange.js'].lineData[218] = 0;
  _$jscoverage['/hashchange.js'].lineData[222] = 0;
  _$jscoverage['/hashchange.js'].lineData[223] = 0;
  _$jscoverage['/hashchange.js'].lineData[225] = 0;
  _$jscoverage['/hashchange.js'].lineData[228] = 0;
  _$jscoverage['/hashchange.js'].lineData[229] = 0;
  _$jscoverage['/hashchange.js'].lineData[231] = 0;
}
if (! _$jscoverage['/hashchange.js'].functionData) {
  _$jscoverage['/hashchange.js'].functionData = [];
  _$jscoverage['/hashchange.js'].functionData[0] = 0;
  _$jscoverage['/hashchange.js'].functionData[1] = 0;
  _$jscoverage['/hashchange.js'].functionData[2] = 0;
  _$jscoverage['/hashchange.js'].functionData[3] = 0;
  _$jscoverage['/hashchange.js'].functionData[4] = 0;
  _$jscoverage['/hashchange.js'].functionData[5] = 0;
  _$jscoverage['/hashchange.js'].functionData[6] = 0;
  _$jscoverage['/hashchange.js'].functionData[7] = 0;
  _$jscoverage['/hashchange.js'].functionData[8] = 0;
  _$jscoverage['/hashchange.js'].functionData[9] = 0;
  _$jscoverage['/hashchange.js'].functionData[10] = 0;
  _$jscoverage['/hashchange.js'].functionData[11] = 0;
  _$jscoverage['/hashchange.js'].functionData[12] = 0;
  _$jscoverage['/hashchange.js'].functionData[13] = 0;
  _$jscoverage['/hashchange.js'].functionData[14] = 0;
  _$jscoverage['/hashchange.js'].functionData[15] = 0;
}
if (! _$jscoverage['/hashchange.js'].branchData) {
  _$jscoverage['/hashchange.js'].branchData = {};
  _$jscoverage['/hashchange.js'].branchData['29'] = [];
  _$jscoverage['/hashchange.js'].branchData['29'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['29'][2] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['43'] = [];
  _$jscoverage['/hashchange.js'].branchData['43'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['43'][2] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['55'] = [];
  _$jscoverage['/hashchange.js'].branchData['55'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['61'] = [];
  _$jscoverage['/hashchange.js'].branchData['61'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['70'] = [];
  _$jscoverage['/hashchange.js'].branchData['70'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['70'][2] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['85'] = [];
  _$jscoverage['/hashchange.js'].branchData['85'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['114'] = [];
  _$jscoverage['/hashchange.js'].branchData['114'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['119'] = [];
  _$jscoverage['/hashchange.js'].branchData['119'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['127'] = [];
  _$jscoverage['/hashchange.js'].branchData['127'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['127'][2] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['135'] = [];
  _$jscoverage['/hashchange.js'].branchData['135'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['166'] = [];
  _$jscoverage['/hashchange.js'].branchData['166'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['168'] = [];
  _$jscoverage['/hashchange.js'].branchData['168'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['205'] = [];
  _$jscoverage['/hashchange.js'].branchData['205'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['217'] = [];
  _$jscoverage['/hashchange.js'].branchData['217'][1] = new BranchData();
  _$jscoverage['/hashchange.js'].branchData['228'] = [];
  _$jscoverage['/hashchange.js'].branchData['228'][1] = new BranchData();
}
_$jscoverage['/hashchange.js'].branchData['228'][1].init(18, 12, 'this !== win');
function visit19_228_1(result) {
  _$jscoverage['/hashchange.js'].branchData['228'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['217'][1].init(18, 12, 'this !== win');
function visit18_217_1(result) {
  _$jscoverage['/hashchange.js'].branchData['217'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['205'][1].init(18, 5, 'timer');
function visit17_205_1(result) {
  _$jscoverage['/hashchange.js'].branchData['205'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['168'][1].init(30, 26, 'e.propertyName === \'title\'');
function visit16_168_1(result) {
  _$jscoverage['/hashchange.js'].branchData['168'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['166'][1].init(26, 17, 'e || window.event');
function visit15_166_1(result) {
  _$jscoverage['/hashchange.js'].branchData['166'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['135'][1].init(18, 7, '!iframe');
function visit14_135_1(result) {
  _$jscoverage['/hashchange.js'].branchData['135'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['127'][2].init(4106, 6, 'ie < 8');
function visit13_127_2(result) {
  _$jscoverage['/hashchange.js'].branchData['127'][2].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['127'][1].init(4100, 12, 'ie && ie < 8');
function visit12_127_1(result) {
  _$jscoverage['/hashchange.js'].branchData['127'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['119'][1].init(18, 5, 'timer');
function visit11_119_1(result) {
  _$jscoverage['/hashchange.js'].branchData['119'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['114'][1].init(18, 6, '!timer');
function visit10_114_1(result) {
  _$jscoverage['/hashchange.js'].branchData['114'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['85'][1].init(54, 14, 'replaceHistory');
function visit9_85_1(result) {
  _$jscoverage['/hashchange.js'].branchData['85'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['70'][2].init(1470, 6, 'ie < 8');
function visit8_70_2(result) {
  _$jscoverage['/hashchange.js'].branchData['70'][2].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['70'][1].init(1464, 12, 'ie && ie < 8');
function visit7_70_1(result) {
  _$jscoverage['/hashchange.js'].branchData['70'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['61'][1].init(335, 17, 'hash !== lastHash');
function visit6_61_1(result) {
  _$jscoverage['/hashchange.js'].branchData['61'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['55'][1].init(92, 36, 'hash.indexOf(REPLACE_HISTORY) !== -1');
function visit5_55_1(result) {
  _$jscoverage['/hashchange.js'].branchData['55'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['43'][2].init(432, 9, 'm && m[0]');
function visit4_43_2(result) {
  _$jscoverage['/hashchange.js'].branchData['43'][2].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['43'][1].init(432, 16, 'm && m[0] || \'#\'');
function visit3_43_1(result) {
  _$jscoverage['/hashchange.js'].branchData['43'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['29'][2].init(75, 16, 'doc && doc.title');
function visit2_29_2(result) {
  _$jscoverage['/hashchange.js'].branchData['29'][2].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].branchData['29'][1].init(75, 22, 'doc && doc.title || \'\'');
function visit1_29_1(result) {
  _$jscoverage['/hashchange.js'].branchData['29'][1].ranCondition(result);
  return result;
}_$jscoverage['/hashchange.js'].lineData[6]++;
KISSY.add(function(S, require) {
  _$jscoverage['/hashchange.js'].functionData[0]++;
  _$jscoverage['/hashchange.js'].lineData[7]++;
  var util = require('util');
  _$jscoverage['/hashchange.js'].lineData[8]++;
  var DomEvent = require('event/dom/base');
  _$jscoverage['/hashchange.js'].lineData[9]++;
  var Dom = require('dom');
  _$jscoverage['/hashchange.js'].lineData[10]++;
  var UA = require('ua'), urlWithoutHash, Special = DomEvent.Special, win = S.Env.host, doc = win.document, REPLACE_HISTORY = '__ks_replace_history__', ie = UA.ieMode, HASH_CHANGE = 'hashchange';
  _$jscoverage['/hashchange.js'].lineData[19]++;
  DomEvent.REPLACE_HISTORY = REPLACE_HISTORY;
  _$jscoverage['/hashchange.js'].lineData[24]++;
  function getIframeDoc(iframe) {
    _$jscoverage['/hashchange.js'].functionData[1]++;
    _$jscoverage['/hashchange.js'].lineData[25]++;
    return iframe.contentWindow.document;
  }
  _$jscoverage['/hashchange.js'].lineData[28]++;
  var POLL_INTERVAL = 50, IFRAME_TEMPLATE = '<html><head><title>' + (visit1_29_1(visit2_29_2(doc && doc.title) || '')) + ' - {hash}</title>{head}</head><body>{hash}</body></html>', getHash = function() {
  _$jscoverage['/hashchange.js'].functionData[2]++;
  _$jscoverage['/hashchange.js'].lineData[42]++;
  var m = location.href.match(/#.+$/);
  _$jscoverage['/hashchange.js'].lineData[43]++;
  return visit3_43_1(visit4_43_2(m && m[0]) || '#');
}, timer, lastHash, poll = function() {
  _$jscoverage['/hashchange.js'].functionData[3]++;
  _$jscoverage['/hashchange.js'].lineData[52]++;
  var hash = getHash(), replaceHistory = 0;
  _$jscoverage['/hashchange.js'].lineData[55]++;
  if (visit5_55_1(hash.indexOf(REPLACE_HISTORY) !== -1)) {
    _$jscoverage['/hashchange.js'].lineData[56]++;
    replaceHistory = 1;
    _$jscoverage['/hashchange.js'].lineData[57]++;
    hash = hash.replace(REPLACE_HISTORY, '');
    _$jscoverage['/hashchange.js'].lineData[59]++;
    location.hash = hash;
  }
  _$jscoverage['/hashchange.js'].lineData[61]++;
  if (visit6_61_1(hash !== lastHash)) {
    _$jscoverage['/hashchange.js'].lineData[65]++;
    hashChange(hash, replaceHistory);
  }
  _$jscoverage['/hashchange.js'].lineData[67]++;
  timer = setTimeout(poll, POLL_INTERVAL);
}, hashChange = visit7_70_1(ie && visit8_70_2(ie < 8)) ? function(hash, replaceHistory) {
  _$jscoverage['/hashchange.js'].functionData[4]++;
  _$jscoverage['/hashchange.js'].lineData[72]++;
  var html = util.substitute(IFRAME_TEMPLATE, {
  hash: util.escapeHtml(hash), 
  head: Dom.isCustomDomain() ? ('<script>' + 'document.' + 'domain = "' + doc.domain + '";</script>') : ''}), iframeDoc = getIframeDoc(iframe);
  _$jscoverage['/hashchange.js'].lineData[83]++;
  try {
    _$jscoverage['/hashchange.js'].lineData[85]++;
    if (visit9_85_1(replaceHistory)) {
      _$jscoverage['/hashchange.js'].lineData[86]++;
      iframeDoc.open('text/html', 'replace');
    } else {
      _$jscoverage['/hashchange.js'].lineData[89]++;
      iframeDoc.open();
    }
    _$jscoverage['/hashchange.js'].lineData[93]++;
    iframeDoc.write(html);
    _$jscoverage['/hashchange.js'].lineData[94]++;
    iframeDoc.close();
  }  catch (e) {
}
} : function() {
  _$jscoverage['/hashchange.js'].functionData[5]++;
  _$jscoverage['/hashchange.js'].lineData[101]++;
  notifyHashChange();
}, notifyHashChange = function() {
  _$jscoverage['/hashchange.js'].functionData[6]++;
  _$jscoverage['/hashchange.js'].lineData[107]++;
  DomEvent.fireHandler(win, HASH_CHANGE, {
  newURL: location.href, 
  oldURL: urlWithoutHash + lastHash});
  _$jscoverage['/hashchange.js'].lineData[111]++;
  lastHash = getHash();
}, setup = function() {
  _$jscoverage['/hashchange.js'].functionData[7]++;
  _$jscoverage['/hashchange.js'].lineData[114]++;
  if (visit10_114_1(!timer)) {
    _$jscoverage['/hashchange.js'].lineData[115]++;
    poll();
  }
}, tearDown = function() {
  _$jscoverage['/hashchange.js'].functionData[8]++;
  _$jscoverage['/hashchange.js'].lineData[119]++;
  if (visit11_119_1(timer)) {
    _$jscoverage['/hashchange.js'].lineData[120]++;
    clearTimeout(timer);
  }
  _$jscoverage['/hashchange.js'].lineData[122]++;
  timer = 0;
}, iframe;
  _$jscoverage['/hashchange.js'].lineData[127]++;
  if (visit12_127_1(ie && visit13_127_2(ie < 8))) {
    _$jscoverage['/hashchange.js'].lineData[134]++;
    setup = function() {
  _$jscoverage['/hashchange.js'].functionData[9]++;
  _$jscoverage['/hashchange.js'].lineData[135]++;
  if (visit14_135_1(!iframe)) {
    _$jscoverage['/hashchange.js'].lineData[136]++;
    var iframeSrc = Dom.getEmptyIframeSrc();
    _$jscoverage['/hashchange.js'].lineData[138]++;
    iframe = Dom.create('<iframe ' + (iframeSrc ? 'src="' + iframeSrc + '"' : '') + ' style="display: none" ' + 'height="0" ' + 'width="0" ' + 'tabindex="-1" ' + 'title="empty"/>');
    _$jscoverage['/hashchange.js'].lineData[148]++;
    Dom.prepend(iframe, doc.documentElement);
    _$jscoverage['/hashchange.js'].lineData[151]++;
    DomEvent.add(iframe, 'load', function() {
  _$jscoverage['/hashchange.js'].functionData[10]++;
  _$jscoverage['/hashchange.js'].lineData[152]++;
  DomEvent.remove(iframe, 'load');
  _$jscoverage['/hashchange.js'].lineData[156]++;
  hashChange(getHash());
  _$jscoverage['/hashchange.js'].lineData[157]++;
  DomEvent.add(iframe, 'load', onIframeLoad);
  _$jscoverage['/hashchange.js'].lineData[158]++;
  poll();
});
    _$jscoverage['/hashchange.js'].lineData[165]++;
    doc.attachEvent('propertychange', function(e) {
  _$jscoverage['/hashchange.js'].functionData[11]++;
  _$jscoverage['/hashchange.js'].lineData[166]++;
  e = visit15_166_1(e || window.event);
  _$jscoverage['/hashchange.js'].lineData[167]++;
  try {
    _$jscoverage['/hashchange.js'].lineData[168]++;
    if (visit16_168_1(e.propertyName === 'title')) {
      _$jscoverage['/hashchange.js'].lineData[169]++;
      getIframeDoc(iframe).title = doc.title + ' - ' + getHash();
    }
  }  catch (e) {
}
});
    _$jscoverage['/hashchange.js'].lineData[182]++;
    var onIframeLoad = function() {
  _$jscoverage['/hashchange.js'].functionData[12]++;
  _$jscoverage['/hashchange.js'].lineData[192]++;
  location.hash = util.trim(getIframeDoc(iframe).body.innerText);
  _$jscoverage['/hashchange.js'].lineData[199]++;
  notifyHashChange();
};
  }
};
    _$jscoverage['/hashchange.js'].lineData[204]++;
    tearDown = function() {
  _$jscoverage['/hashchange.js'].functionData[13]++;
  _$jscoverage['/hashchange.js'].lineData[205]++;
  if (visit17_205_1(timer)) {
    _$jscoverage['/hashchange.js'].lineData[206]++;
    clearTimeout(timer);
  }
  _$jscoverage['/hashchange.js'].lineData[208]++;
  timer = 0;
  _$jscoverage['/hashchange.js'].lineData[209]++;
  DomEvent.detach(iframe);
  _$jscoverage['/hashchange.js'].lineData[210]++;
  Dom.remove(iframe);
  _$jscoverage['/hashchange.js'].lineData[211]++;
  iframe = 0;
};
  }
  _$jscoverage['/hashchange.js'].lineData[215]++;
  Special[HASH_CHANGE] = {
  setup: function() {
  _$jscoverage['/hashchange.js'].functionData[14]++;
  _$jscoverage['/hashchange.js'].lineData[217]++;
  if (visit18_217_1(this !== win)) {
    _$jscoverage['/hashchange.js'].lineData[218]++;
    return;
  }
  _$jscoverage['/hashchange.js'].lineData[222]++;
  lastHash = getHash();
  _$jscoverage['/hashchange.js'].lineData[223]++;
  urlWithoutHash = location.href.replace(/#.+/, '');
  _$jscoverage['/hashchange.js'].lineData[225]++;
  setup();
}, 
  tearDown: function() {
  _$jscoverage['/hashchange.js'].functionData[15]++;
  _$jscoverage['/hashchange.js'].lineData[228]++;
  if (visit19_228_1(this !== win)) {
    _$jscoverage['/hashchange.js'].lineData[229]++;
    return;
  }
  _$jscoverage['/hashchange.js'].lineData[231]++;
  tearDown();
}};
});
